import greenfoot.*; 

/**
 * A projectile that can hit doughnuts.
 * 
 * @author Poul Henriksen
 */
public class Projectile extends SmoothMover
{
    /** The damage this projectile will deal */
    private static final int damage = 16;
    
    /** A projectile looses one life each act, and will disappear when life = 0 */
    private int life = 30;
    
    public Projectile()
    {
        
    }
    
    public Projectile(Vector speed, int rotation)
    {
        super(speed);
        setRotation(rotation);
        addToVelocity(new Vector(rotation, 15));
        Greenfoot.playSound("EnergyGun.wav");
    }
    
    /**
     * The projectile will damage doughnuts if it hits them.
     */
    public void act()
    {
        if(life <= 0) {
            getWorld().removeObject(this);
        } 
        else {
            life--;
            move();
            checkDoughnutHit();
        }
    }
    
    /**
     * Check whether we have hit an doughnut.
     */
    private void checkDoughnutHit()
    {
        Doughnut doughnut = (Doughnut) getOneIntersectingObject(Doughnut.class);
        if (doughnut != null) 
        {
            getWorld().removeObject(this);
            doughnut.hit(damage);
        }
    }
}